@@ -256,12 +256,20 @@ isb.splsdacox <- function(X, Y,
           survival_model <- cox_model$survival_model
         }
 
+        all_scores <- NULL
+        for(b in names(lst_sb.spls)){
+          aux_scores <- lst_sb.spls[[b]]$X$scores
+          colnames(aux_scores) <- paste0(colnames(aux_scores), "_", b)
+          all_scores <- cbind(all_scores, aux_scores)
+        }
+
         t2 <- Sys.time()
         time <- difftime(t2,t1,units = "mins")
 
         # invisible(gc())
         return(isb.splsdacox_dynamic_class(list(X = list("data" = if(returnData) X_norm else NA,
-                                                "x.mean" = xmeans, "x.sd" = xsds),
+                                                         "scores" = all_scores,
+                                                         "x.mean" = xmeans, "x.sd" = xsds),
                                       Y = list("data" = Yh,
                                                "y.mean" = ymeans, "y.sd" = ysds),
                                       survival_model = survival_model,
@@ -396,7 +404,7 @@ cv.isb.splsdacox <- function(X, Y,
   # tol Numeric. Tolerance for solving: solve(t(P) %*% W) (default: 1e-15).
   tol = 1e-10
 
-  t1 <- Sys.time()
+  t1_true <- Sys.time()
   y.center = y.scale = FALSE
   FREQ_CUT <- 95/5
 
@@ -559,8 +567,8 @@ cv.isb.splsdacox <- function(X, Y,
   #### ### #
   func_call <- match.call()
 
-  t2 <- Sys.time()
-  time <- difftime(t2,t1,units = "mins")
+  t2_true <- Sys.time()
+  time <- difftime(t2_true,t1_true,units = "mins")
 
   # invisible(gc())
   return(cv.isb.splsdacox_dynamic_class(list(X = list("data" = if(returnData) X_norm else NA,
